@@ -1,6 +1,5 @@
 """Utils for caching functions."""
 import json
-
 from functools import wraps
 
 from utils.cache_impl import _Cache
@@ -13,15 +12,16 @@ def cache(cache_name, timeout=CACHE_DEFAULT_TIMEOUT):
     """Wrap class Cache as decorator."""
 
     def cache_inner(func):
-
         @wraps(func)
         def cache_inner_inner(*args, **kwargs):
-            cache_key = json.dumps({
-                'cache_name': cache_name,
-                'function_name': func.__name__,
-                'kwargs': kwargs,
-                'args': args,
-            })
+            cache_key = json.dumps(
+                {
+                    'cache_name': cache_name,
+                    'function_name': func.__name__,
+                    'kwargs': kwargs,
+                    'args': args,
+                }
+            )
 
             def fallback():
                 return func(*args, **kwargs)
@@ -29,4 +29,5 @@ def cache(cache_name, timeout=CACHE_DEFAULT_TIMEOUT):
             return _Cache(cache_name, timeout).get(cache_key, fallback)
 
         return cache_inner_inner
+
     return cache_inner
